@@ -15,7 +15,7 @@
 //! With default configuration, `lib.rs` must include the following lines for reflection.
 //!
 //! ```ignore
-//! static FILE_DESCRIPTOR: Lazy<FileDescriptor> = Lazy::new(|| FileDescriptor::decode(
+//! static DESCRIPTOR_POOL: Lazy<DescriptorPool> = Lazy::new(|| DescriptorPool::decode(
 //!     include_bytes!(concat!(env!("OUT_DIR"), "file_descriptor_set.bin")).as_ref()
 //! ).unwrap());
 //!
@@ -23,14 +23,14 @@
 //! include!(concat!(env!("OUT_DIR"), "protobuf.rs"));
 //! ```
 #![warn(missing_debug_implementations, missing_docs)]
-#![doc(html_root_url = "https://docs.rs/prost-reflect-build/0.7.0/")]
+#![doc(html_root_url = "https://docs.rs/prost-reflect-build/0.8.0/")]
 
 use std::{
     env, fs, io,
     path::{Path, PathBuf},
 };
 
-use prost_reflect::FileDescriptor;
+use prost_reflect::DescriptorPool;
 
 /// Configuration builder for prost-reflect code generation.
 ///
@@ -57,7 +57,7 @@ impl Default for Builder {
 
         Self {
             file_descriptor_set_path,
-            file_descriptor_expr: "crate::FILE_DESCRIPTOR".into(),
+            file_descriptor_expr: "crate::DESCRIPTOR_POOL".into(),
         }
     }
 }
@@ -82,13 +82,13 @@ impl Builder {
     }
 
     /// Set the file descriptor expression for reflection.
-    /// By default, `crate::FILE_DESCRIPTOR` is used as the expression.
+    /// By default, `crate::DESCRIPTOR_POOL` is used as the expression.
     /// In that case, `lib.rs` should contain the following lines,
     ///
     /// ```ignore
-    /// static FILE_DESCRIPTOR: Lazy<FileDescriptor> = Lazy::new(||
-    ///     FileDescriptor::decode(include_bytes!(
-    ///         concat!(env!("OUT_DIR"), "file_descriptor_set.bin")
+    /// static DESCRIPTOR_POOL: Lazy<DescriptorPool> = Lazy::new(||
+    ///     DescriptorPool::decode(include_bytes!(
+    ///         concat!(env!("OUT_DIR"), "/file_descriptor_set.bin")
     ///     ).as_ref()).unwrap()
     /// );
     /// ```
@@ -129,7 +129,7 @@ impl Builder {
             .compile_protos(protos, includes)?;
 
         let buf = fs::read(&self.file_descriptor_set_path)?;
-        let descriptor = FileDescriptor::decode(buf.as_ref()).expect("Invalid file descriptor");
+        let descriptor = DescriptorPool::decode(buf.as_ref()).expect("Invalid file descriptor");
 
         for message in descriptor.all_messages() {
             let full_name = message.full_name();
@@ -138,7 +138,7 @@ impl Builder {
                 .type_attribute(
                     full_name,
                     &format!(
-                        r#"#[prost_reflect(file_descriptor = "{}", message_name = "{}")]"#,
+                        r#"#[prost_reflect(descriptor_pool = "{}", message_name = "{}")]"#,
                         self.file_descriptor_expr, full_name,
                     ),
                 );
